#!/bin/sh
#----------------------------------------------------------------------------
# /tmp/install.sh  - install script for OpenLDAP client
#
# Copyright (c) 2009-2020  The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2009-11-28  jed
# Last Update:  $Id: install.sh 75519 2020-04-30 15:04:10Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

# load eislib etc.
. /var/install/include/eislib
. /var/install/include/jedlib

module_name=ldapclient
old_deinstallfile=/var/install/deinstall/openldap

#exec 2> /tmp/${module_name}-install.sh-trace$$.log
#set -x

myecho --pack ${module_name} --info "running install.sh ..."

# update shared library file
update_jedlib ${module_name}

# user and group
user='ldap'
group='ldap'
uid=''
gid=''
name='LDAP user'
homedir='/home/ldap'
shell='/bin/false'
pass='!'

# check group
if ! getent group ${group} >/dev/null 2>&1
then
    myecho --pack ${module_name} "adding group '${group}' ..."
    /var/install/bin/add-group ${group}
fi

gid=`getent group ${group} | cut -d: -f3`

# check user
if ! getent passwd ${user} >/dev/null 2>&1
then
    myecho --pack ${module_name} "adding user '${user}' ..."
    /var/install/bin/add-user -l ${user} "" "${uid}" "${gid}" "${name}" "${homedir}" "${shell}"
else
    myecho --pack ${module_name} "user '${user}' already exists ..."

    # user exists, check if group has properly been set
    gidusr=`getent passwd ${user} | cut -d: -f4`

    if [ "${gidusr}" != "${gid}" ]
    then
        gname=`getent group ${gidusr} | cut -d: -f1`

        if [ "${gname}" != "${group}" ]
        then
            myecho --pack ${module_name} --warn "Attention, the gid of the group '${group}' (${gidusr}) has been changed. It should be '${gid}'!"
        fi

        myecho --pack ${module_name} "modifying group of user '${user}', '${gname}' -> '${group}' ..."
        /var/install/bin/modify-user -g "${user}" "${group}"
    fi

    # user exists, make sure that the homedir has properly set
    hname=`getent passwd ${user} | cut -d: -f6`

    if [ "${hname}" != "${homedir}" ]
    then
        myecho --pack ${module_name} "modifying home directory of user '${user}', '${hname}' -> '${homedir}' ..."
        /var/install/bin/modify-user -d "${user}" "${homedir}"
    fi

    # user exists, make sure that the shell has properly set
    sname=`getent passwd ${user} | cut -d: -f7`

    if [ "${sname}" != "${shell}" ]
    then
        myecho --pack ${module_name} "modifying shell of user '${user}', '${sname}' -> '${shell}' ..."
        /var/install/bin/modify-user -s "${user}" "${shell}"
    fi
fi

if [ -f ${old_deinstallfile} ]
then
    # removing ldapclient files from openldap deinstallation script
    myecho --pack ${module_name} "updating openldap deinstallation script ..."
    cp ${old_deinstallfile} ${old_deinstallfile}.tmp
    sed 's#rm -f /usr/bin/ldap#\# deactivated by ldapclient package\n\#rm -f /usr/bin/ldap#g' ${old_deinstallfile}.tmp > ${old_deinstallfile}
    rm -f ${old_deinstallfile}.tmp
fi

# menue entry does not exist - create it
myecho --pack ${module_name} "adding ${module_name} module menu  ..."
/var/install/bin/add-menu --menu "setup.services.menu" "setup.services.${module_name}.menu" "OpenLDAP Client"

# install/update package configuration file
silent=''
if called_from_install --pack "${module_name}"
then
    silent='--quiet'
fi

update=false
if install_config ${silent} ${module_name}
then
    update=true
fi

# configuration
myecho --pack ${module_name} "creating ${module_name} configuration ..."

# updated installation
/var/install/config.d/${module_name}.sh

if [ -f /etc/init.d/${module_name} ]
then
    /etc/init.d/${module_name} restart
fi

exit 0
